@@ -38,6 +38,8 @@
 #include <AkonadiCore/searchquery.h>
 #include <Akonadi/KMime/MessageFlags>
 
+#include <QElapsedTimer>
+
 Q_DECLARE_METATYPE(QSet<qint64>)
 Q_DECLARE_METATYPE(QList<qint64>)
 
@@ -51,27 +53,6 @@ private:
     QString noteDir;
     QString calendarDir;
 
-    bool removeDir(const QString &dirName)
-    {
-        bool result = true;
-        QDir dir(dirName);
-
-        if (dir.exists(dirName)) {
-            Q_FOREACH (QFileInfo info, dir.entryInfoList(QDir::NoDotAndDotDot | QDir::System | QDir::Hidden  | QDir::AllDirs | QDir::Files, QDir::DirsFirst)) {
-                if (info.isDir()) {
-                    result = removeDir(info.absoluteFilePath());
-                } else {
-                    result = QFile::remove(info.absoluteFilePath());
-                }
-
-                if (!result) {
-                    return result;
-                }
-            }
-            result = dir.rmdir(dirName);
-        }
-        return result;
-    }
     void resultSearch()
     {
         QFETCH(QString, query);
@@ -80,14 +61,16 @@ private:
         QFETCH(QSet<qint64>, expectedResult);
 
         qDebug() << "starting search";
+        QElapsedTimer t;
+        t.start();
         SearchPlugin plugin;
         const QSet<qint64> result = plugin.search(query, collections, mimeTypes);
-        qDebug() << result;
+        qDebug() << "result:" << result << "(in" << t.elapsed() << "ms)";
         QCOMPARE(result, expectedResult);
     }
 
 private Q_SLOTS:
-    void init()
+    void initTestCase()
     {
         emailDir = QDir::tempPath() + QLatin1String("/searchplugintest/email/");
         emailContactsDir = QDir::tempPath() + QLatin1String("/searchplugintest/emailcontacts/");
@@ -96,15 +79,11 @@ private Q_SLOTS:
         calendarDir = QDir::tempPath() + QLatin1String("/searchplugintest/calendar/");
 
         QDir dir;
-        QVERIFY(removeDir(emailDir));
+        QVERIFY(QDir(QDir::tempPath() + QStringLiteral("/searchplugintest")).removeRecursively());
         QVERIFY(dir.mkpath(emailDir));
-        QVERIFY(removeDir(emailContactsDir));
         QVERIFY(dir.mkpath(emailContactsDir));
-        QVERIFY(removeDir(contactsDir));
         QVERIFY(dir.mkpath(contactsDir));
-        QVERIFY(removeDir(noteDir));
         QVERIFY(dir.mkpath(noteDir));
-        QVERIFY(removeDir(calendarDir));
         QVERIFY(dir.mkpath(calendarDir));
 
         qDebug() << "indexing sample data";
@@ -201,9 +180,11 @@ private Q_SLOTS:
             msg->bcc()->addAddress("bcc@test.com", QStringLiteral("Jane Doe"));
             msg->date()->setDateTime(QDateTime(QDate(2014, 11, 11), QTime(13, 0, 0)));
             msg->replyTo()->from7BitString("test@kde.org");
-            KMime::Headers::Generic *header = new KMime::Headers::Generic("Resent-From", msg.get(), QStringLiteral("resent@kde.org"), "utf-8");
+            KMime::Headers::Generic *header = new KMime::Headers::Generic("Resent-From");
+            header->fromUnicodeString(QStringLiteral("resent@kde.org"), "utf-8");
             msg->setHeader(header);
-            header = new KMime::Headers::Generic("List-Id", msg.get(), QStringLiteral("KDE PIM <kde-pim.kde.org>"), "utf-8");
+            header = new KMime::Headers::Generic("List-Id");
+            header->fromUnicodeString(QStringLiteral("KDE PIM <kde-pim.kde.org>"), "utf-8");
             msg->setHeader(header);
 
             msg->assemble();
@@ -436,6 +417,11 @@ private Q_SLOTS:
         Akonadi::Search::SearchStore::overrideSearchStores(QList<Akonadi::Search::SearchStore *>() << emailSearchStore << contactSearchStore << noteSearchStore << calendarSearchStore);
     }
 
+    void cleanupTestCase()
+    {
+        QVERIFY(QDir(QDir::tempPath() + QStringLiteral("/searchplugintest")).removeRecursively());
+    }
+
     void testCalendarSearch_data()
     {
         QTest::addColumn<QString>("query");
